==> invoice-client-4.1.54-20231213.034158-4-sources.jar: com/xforceplus/seller/invoice/client/model/NotMakeOutInvoiceResult.java <==
package com.xforceplus.seller.invoice.client.model;

import io.swagger.annotations.ApiModelProperty;

import java.util.List;
import java.util.Map;

public class NotMakeOutInvoiceResult {

    @ApiModelProperty(value = "含税总金额")
    private String totalTaxAmount;

    @ApiModelProperty(value = "不含税总金额")
    private String totalWithoutAmount;

    @ApiModelProperty(value = "总数")
    private Long total;

    @ApiModelProperty("全部全选条件")
    private Map<String, Object> condition;

    @ApiModelProperty("未开发票信息")
    private List<PreInvoiceInfoPolling> preInvoices;


    public String getTotalTaxAmount() {
        return totalTaxAmount;
    }

    public void setTotalTaxAmount(String totalTaxAmount) {
        this.totalTaxAmount = totalTaxAmount;
    }

    public String getTotalWithoutAmount() {
        return totalWithoutAmount;
    }

    public void setTotalWithoutAmount(String totalWithoutAmount) {
        this.totalWithoutAmount = totalWithoutAmount;
    }

    public Long getTotal() {
        return total;
    }

    public void setTotal(Long total) {
        this.total = total;
    }

    public List<PreInvoiceInfoPolling> getPreInvoices() {
        return preInvoices;
    }

    public void setPreInvoices(List<PreInvoiceInfoPolling> preInvoices) {
        this.preInvoices = preInvoices;
    }

    public Map<String, Object> getCondition() {
        return condition;
    }

    public void setCondition(Map<String, Object> condition) {
        this.condition = condition;
    }

    @Override
    public String toString() {
        return "NotMakeOutInvoiceResult{" +
                "totalTaxAmount='" + totalTaxAmount + '\'' +
                ", totalWithoutAmount='" + totalWithoutAmount + '\'' +
                ", total=" + total +
                ", condition=" + condition +
                ", preInvoices=" + preInvoices +
                '}';
    }
}

==> invoice-client-4.2.10-20250926.063103-1-sources.jar: com/xforceplus/seller/invoice/client/model/NotMakeOutInvoiceResult.java <==
package com.xforceplus.seller.invoice.client.model;

import io.swagger.annotations.ApiModelProperty;

import java.util.List;
import java.util.Map;

public class NotMakeOutInvoiceResult {

    @ApiModelProperty(value = "含税总金额")
    private String totalTaxAmount;

    @ApiModelProperty(value = "不含税总金额")
    private String totalWithoutAmount;

    @ApiModelProperty(value = "生成失败原因")
    private String processRemark;

    @ApiModelProperty(value = "总数")
    private Long total;

    @ApiModelProperty("全部全选条件")
    private Map<String, Object> condition;

    @ApiModelProperty("未开发票信息")
    private List<PreInvoiceInfoPolling> preInvoices;


    public String getTotalTaxAmount() {
        return totalTaxAmount;
    }

    public void setTotalTaxAmount(String totalTaxAmount) {
        this.totalTaxAmount = totalTaxAmount;
    }

    public String getTotalWithoutAmount() {
        return totalWithoutAmount;
    }

    public void setTotalWithoutAmount(String totalWithoutAmount) {
        this.totalWithoutAmount = totalWithoutAmount;
    }

    public String getProcessRemark() {
        return processRemark == null ? null : processRemark.trim();
    }

    public void setProcessRemark(String processRemark) {
        this.processRemark = processRemark == null ? null : processRemark.trim();
    }

    public Long getTotal() {
        return total;
    }

    public void setTotal(Long total) {
        this.total = total;
    }

    public List<PreInvoiceInfoPolling> getPreInvoices() {
        return preInvoices;
    }

    public void setPreInvoices(List<PreInvoiceInfoPolling> preInvoices) {
        this.preInvoices = preInvoices;
    }

    public Map<String, Object> getCondition() {
        return condition;
    }

    public void setCondition(Map<String, Object> condition) {
        this.condition = condition;
    }

    @Override
    public String toString() {
        return "NotMakeOutInvoiceResult{" +
                "totalTaxAmount='" + totalTaxAmount + '\'' +
                ", totalWithoutAmount='" + totalWithoutAmount + '\'' +
                ", processRemark='" + processRemark + '\'' +
                ", total=" + total +
                ", condition=" + condition +
                ", preInvoices=" + preInvoices +
                '}';
    }
}
